@@ -1,8 +1,10 @@
 #![cfg_attr(feature = "internal_benches", allow(unstable_features), feature(test))]
 
+pub mod g2;
 pub mod g3;
 pub mod g4;
 
+pub mod sm2;
 pub mod sm3;
 pub mod sm4;
 
